// Generated by CoffeeScript 1.9.0
"use strict";
var Gatelogs, Producer, async, exec, fs, logger, spawn, _,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  __hasProp = {}.hasOwnProperty;

fs = require("fs");

spawn = require("child_process").spawn;

exec = require("child_process").exec;

async = require('async');

_ = require('lodash');

logger = require("omg-logger");

Producer = require("class_node_producer");

Gatelogs = (function(_super) {
  var clearLogFile, isRunning, logConfigPath, logOutputFilePath, logTimer, restartRsyslog, tail, webLogConfigPath, writeNewConfig;

  __extends(Gatelogs, _super);

  isRunning = false;

  logConfigPath = "/etc/rsyslog.d/50-default.conf";

  webLogConfigPath = "/etc/rsyslog.d/51-weblog.conf";

  logOutputFilePath = "/tmp/logs/webSyslog.olg";

  writeNewConfig = function(parallelCallback) {

    /* read config, replace path and write it to new config */
    var newConfig, originalLogConfig, originalLogConfigLines, pathToReplace, regex;
    originalLogConfig = (fs.readFileSync(logConfigPath)).toString();
    originalLogConfigLines = originalLogConfig.split("\n");
    pathToReplace = _.last(originalLogConfigLines[2].split(" "));
    pathToReplace = pathToReplace.split(";")[0];
    regex = new RegExp(pathToReplace, 'g');
    newConfig = originalLogConfig.replace(regex, logOutputFilePath);
    return fs.writeFile(webLogConfigPath, newConfig, function(err) {
      if (err) {
        logger.error(err.message);
        parallelCallback("error on writeFile");
      } else {
        logger.debug("wrote config to weblog config");
        parallelCallback(null);
      }
    });
  };

  clearLogFile = function(parallelCallback) {
    return fs.writeFile(logOutputFilePath, "", function(err) {
      if (err) {
        logger.error(err.message);
        parallelCallback("error on writeFile");
      } else {
        logger.debug("Cleared log file");
        parallelCallback(null);
      }
    });
  };

  restartRsyslog = function(seriesCallback) {
    var child;
    return child = exec("service rsyslog restart", function(error, stdout, stderr) {
      if (!error) {
        seriesCallback(null);
      }
      if (stdout) {
        logger.debug(stdout);
      }
      if (stderr) {
        logger.debug(stderr);
      }
      if (error) {
        logger.error("exec error: " + error.message);
        seriesCallback(error);
      }
    });
  };

  tail = void 0;

  logTimer = void 0;

  function Gatelogs() {
    var startTailing;
    Gatelogs.__super__.constructor.call(this, "gatelogs");
    startTailing = (function(_this) {
      return function(seriesCallback) {
        var handleStdOut;
        tail = spawn("tail", ["-f", logOutputFilePath]);
        handleStdOut = function(data) {
          var lines;
          lines = data.toString("utf-8");
          lines = lines.split("\n");
          lines.pop();
          _this.sendData(lines, true);
        };
        tail.stdout.on("data", handleStdOut);
        tail.on("exit", function(err, code) {
          _this.sendStatus("stopped");
          return _this.stop();
        });
        _this.sendStatus("started");
        _this.sendStatus("running");
        return seriesCallback(null);
      };
    })(this);
    this.start = (function(_this) {
      return function(duration) {
        var restartAndTail;
        if (!tail || tail.killed) {
          if (!duration) {
            _this.sendError("Specify a duration!");
          }
          restartAndTail = function() {
            return async.series([restartRsyslog, startTailing]);
          };
          async.parallel([writeNewConfig, clearLogFile], restartAndTail);
        } else {
          logger.warn("gatelogs already running");
          _this.sendError("gatelogs already running");
          _this.sendStatus("running");
        }
        if (logTimer) {
          logger.debug("clearing logger timeout");
          clearTimeout(logTimer);
        }
        logger.debug("setting logger timeout to " + duration + " minutes");
        return logTimer = setTimeout(_this.stop, duration * 1000 * 60);
      };
    })(this);
    this.stop = (function(_this) {
      return function() {
        logger.debug("stop was called");
        if (tail && !tail.killed) {
          tail.kill();
          logger.info("killing tail");
          if (logTimer) {
            logger.debug("clearing timeout");
            clearTimeout(logTimer);
          }
          return fs.unlink(webLogConfigPath, function(err) {
            if (err) {
              logger.error(err.message);
              _this.sendError("Could not delete temporary rsyslog config file: " + err.message);
              return;
            }
            if (!err) {
              logger.debug("deleted log config");
            }
            return restartRsyslog(function(error) {
              if (!error) {
                tail = void 0;
                _this.sendStatus("stopped");
              }
              if (error) {
                _this.sendError("restarting syslog failed after stopping tail: " + error.message);
              }
              if (error) {
                return logger.warn("restarting syslog failed after stopping tail: " + error.message);
              }
            });
          });
        }
      };
    })(this);
    this.getAllLogs = (function(_this) {
      return function(outputCallback) {
        var thisManyLines;
        thisManyLines = 20000;
        exec("tail -" + thisManyLines + " " + logOutputFilePath, function(error, stdout, stderr) {
          var lines;
          if (error) {
            logger.error(error);
          }
          if (error) {
            _this.replyData(error, outputCallback);
          }
          if (stderr) {
            logger.warn(stderr);
          }
          if (stderr) {
            _this.replyData(stderr, outputCallback);
          }
          if (stdout) {
            logger.debug(stdout);
          }
          if (stdout) {
            lines = stdout.toString("utf-8");
            lines = lines.split("\n");
            lines.pop();
            if (stdout) {
              return _this.replyData(lines, outputCallback);
            }
          }
        });
        return;
        return fs.readFile(logOutputFilePath, function(err, data) {
          var lines;
          if (err) {
            outputCallback(err);
            logger.error(err.message);
          }
          lines = data.toString("utf-8");
          lines = lines.split("\n");
          lines.pop();
          return this.replyData(lines);
        });
      };
    })(this);
  }

  return Gatelogs;

})(Producer);

module.exports = new Gatelogs();
