// Generated by CoffeeScript 1.9.0

/*
* prod_systeminfo
*
* Copyright (c) 2014 Johannes Noe
* Licensed under the MIT license.
 */

/*jshint expr:true */
'use strict';
var Producer, SystemInfo, async, child_process, debug, fs, getCertValidity, getLocalCert, getMultiple, getSystemInfo, logger, multipleCommandsToRun, path, rootProcessPackageJsonPath, webuiVersion, _,
  __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  __hasProp = {}.hasOwnProperty;

child_process = require('child_process');

async = require('async');

_ = require('lodash');

logger = require("omg-logger");

fs = require('fs');

path = require('path');

debug = require("debug")("omg-systeminfo");

Producer = require("class_node_producer");

getSystemInfo = function(cb) {
  return child_process.exec("LC_ALL=C omgsysteminfo --json 2>/dev/null", function(error, stdout, stderr) {
    if (error) {
      logger.error("omgsysteminfo: " + error);
    }
    if (stderr) {
      console.log(stderr);
    }
    if (stdout) {
      stdout = JSON.parse(stdout);
    }
    return cb(null, stdout);
  });
};

getLocalCert = function(cb) {
  return child_process.exec('LC_ALL=C openssl x509 -in /data/cert.pem -noout -subject 2>/dev/null', function(error, stdout, stderr) {
    var certInfo;
    if (error) {
      logger.error("getLocalCert: " + error);
    }
    if (stderr) {
      console.log(stderr);
    }
    if (stdout) {
      certInfo = {};
      stdout = stdout.split("subject= /")[1];
      stdout = stdout.split("/");
      _.each(stdout, function(certPart) {
        certPart = certPart.split("=");
        return certInfo[certPart[0]] = certPart[1];
      });
      return cb(null, certInfo);
    } else {
      return cb(null, "");
    }
  });
};

getCertValidity = function(cb) {
  return child_process.exec('LC_ALL=C [ -e /data/cert.pem ] && openssl x509 -in /data/cert.pem -noout -enddate | awk -F "=" \'{print $2}\' | awk -F " " \'{print $1" "$2" "$4" "$5}\' || echo No Cert found!', function(error, stdout, stderr) {
    if (error) {
      logger.error("cert validity: " + error);
      cb(error);
    }
    if (stderr) {
      cb(stderr);
    }
    if (stdout) {
      stdout = stdout.replace("\n", "");
      return cb(null, stdout);
    }
  });
};

getMultiple = function(commandObject, cb) {
  var args, child, command, returnObject;
  args = commandObject.command.split(" ");
  command = args.shift();
  debug(command);
  debug(args);
  child = child_process.spawn("" + command, args);
  returnObject = {};
  child.stdout.on("data", function(stdout) {
    stdout = stdout.toString();
    return returnObject[commandObject.name] = stdout;
  });
  child.stderr.on("data", function(stderr) {
    return logger.warn(stderr);
  });
  child.on("error", function(error) {
    return logger.error(error + commandObject.command);
  });
  return child.on("close", function(code) {
    return cb(null, returnObject);
  });
};

multipleCommandsToRun = [
  {
    name: "ifconfig",
    command: "ifconfig -a"
  }, {
    name: "pscallp",
    command: "pscallp"
  }, {
    name: "dmesg",
    command: "dmesg"
  }, {
    name: "procs",
    command: "ps ax"
  }, {
    name: "netstat",
    command: "netstat -an --inet"
  }
];

rootProcessPackageJsonPath = (path.dirname(require.main.filename)) + "/package.json";

webuiVersion = void 0;

fs.exists(rootProcessPackageJsonPath, function(exists) {
  var packageJson;
  if (exists) {
    packageJson = require(rootProcessPackageJsonPath);
    return webuiVersion = packageJson.version;
  }
});

SystemInfo = (function(_super) {
  var isRunning;

  __extends(SystemInfo, _super);

  isRunning = false;

  function SystemInfo() {
    this.subscribe = __bind(this.subscribe, this);
    var getNewData, run;
    SystemInfo.__super__.constructor.call(this, "systeminfo", 15 * 1000);
    run = (function(_this) {
      return function() {
        async.map(multipleCommandsToRun, getMultiple, function(err, results) {
          var returnObject;
          if (err) {
            logger.error(err);
            _this.sendError(err);
            return;
          }
          returnObject = {};
          _.each(results, function(object) {
            return _.each(object, function(data, propName) {
              return returnObject[propName] = data;
            });
          });
          return _this.sendData(returnObject);
        });
        return async.parallel([getSystemInfo, getLocalCert, getCertValidity], function(err, results) {
          var sslcert, sslvalid, systeminfo;
          systeminfo = results[0], sslcert = results[1], sslvalid = results[2];
          systeminfo.sslcert = {
            Company: sslcert,
            "valid until": sslvalid
          };
          systeminfo.webuiVersion = webuiVersion;
          return _this.sendData(systeminfo);
        });
      };
    })(this);
    run();
    getNewData = false;
    this.start = (function(_this) {
      return function() {
        _this.debug("starting");
        run();
        if (getNewData) {
          clearInterval(getNewData);
        }
        return getNewData = setInterval(run, 20 * 1000);
      };
    })(this);
    this.stop = (function(_this) {
      return function() {
        if (getNewData) {
          clearInterval(getNewData);
        }
        return isRunning = false;
      };
    })(this);
  }

  SystemInfo.prototype.subscribe = function() {
    if (!isRunning) {
      isRunning = true;
      this.start();
    }
    return SystemInfo.__super__.subscribe.apply(this, arguments);
  };

  return SystemInfo;

})(Producer);

module.exports = new SystemInfo();
